@@ -181,23 +181,35 @@ void BTDiscovery::BTDiscoveryReDiscover()
 	if (1) {
 #endif
 		m_btValid = true;
-#if !defined(Q_OS_ANDROID)
+
 		if (discoveryAgent == nullptr) {
 			discoveryAgent = new QBluetoothDeviceDiscoveryAgent(this);
+			discoveryAgent->setLowEnergyDiscoveryTimeout(3 * 60 * 1000); // search for three minutes
 			connect(discoveryAgent, &QBluetoothDeviceDiscoveryAgent::deviceDiscovered, this, &BTDiscovery::btDeviceDiscovered);
+			connect(discoveryAgent, &QBluetoothDeviceDiscoveryAgent::finished, this, &BTDiscovery::btDeviceDiscoveryFinished);
+			connect(discoveryAgent, &QBluetoothDeviceDiscoveryAgent::canceled, this, &BTDiscovery::btDeviceDiscoveryFinished);
+			connect(discoveryAgent, QOverload<QBluetoothDeviceDiscoveryAgent::Error>::of(&QBluetoothDeviceDiscoveryAgent::error),
+				[this](QBluetoothDeviceDiscoveryAgent::Error error){
+					qDebug() << "device discovery received error" << discoveryAgent->errorString();
+				});
+			qDebug() << "discovery methods" << (int)QBluetoothDeviceDiscoveryAgent::supportedDiscoveryMethods();
 		}
+#if defined(Q_OS_ANDROID)
+		// on Android, we cannot scan for classic devices - we just get the paired ones
 		qDebug() << "starting BLE discovery";
-		discoveryAgent->start();
-#else
+		discoveryAgent->start(QBluetoothDeviceDiscoveryAgent::LowEnergyMethod);
 		getBluetoothDevices();
 		// and add the paired devices to the internal data
 		// So behaviour is same on Linux/Bluez stack and
 		// Android/Java stack with respect to discovery
 		for (int i = 0; i < btPairedDevices.length(); i++)
-			btDeviceDiscoveredMain(btPairedDevices[i]);
-#endif
+			btDeviceDiscoveredMain(btPairedDevices[i], true);
+#else
+		qDebug() << "starting BT/BLE discovery";
+		discoveryAgent->start();
 		for (int i = 0; i < btPairedDevices.length(); i++)
 			qDebug() << "Paired =" << btPairedDevices[i].name << btPairedDevices[i].address;
+#endif
 
 #if defined(Q_OS_IOS) || (defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID))
 		QTimer timer;
@@ -247,6 +259,15 @@ QString markBLEAddress(const QBluetoothDeviceInfo *device)
 	return btDeviceAddress(device, isBle);
 }
 
+void BTDiscovery::btDeviceDiscoveryFinished()
+{
+	qDebug() << "BT/BLE finished discovery";
+	QList<QBluetoothDeviceInfo> devList = discoveryAgent->discoveredDevices();
+	for (QBluetoothDeviceInfo device: devList) {
+		qDebug() << device.name() << device.address().toString();
+	}
+}
+
 void BTDiscovery::btDeviceDiscovered(const QBluetoothDeviceInfo &device)
 {
 	btPairedDevice this_d;
@@ -268,10 +289,10 @@ void BTDiscovery::btDeviceDiscovered(const QBluetoothDeviceInfo &device)
 	saveBtDeviceInfo(btDeviceAddress(&device, false), device);
 #endif
 
-	btDeviceDiscoveredMain(this_d);
+	btDeviceDiscoveredMain(this_d, false);
 }
 
-void BTDiscovery::btDeviceDiscoveredMain(const btPairedDevice &device)
+void BTDiscovery::btDeviceDiscoveredMain(const btPairedDevice &device, bool fromPaired)
 {
 	btVendorProduct btVP;
 
@@ -282,7 +303,7 @@ void BTDiscovery::btDeviceDiscoveredMain(const btPairedDevice &device)
 	else
 		newDevice = device.name;
 
-	qDebug() << "Found new device:" << newDevice << device.address;
+	qDebug() << (fromPaired ? "Paired device" : "Discovered new device:") << newDevice << device.address;
 	if (newDC) {
 		QString vendor = dc_descriptor_get_vendor(newDC);
 		qDebug() << "this could be a " + vendor + " " + newDevice;
