@@ -20,11 +20,14 @@
 
 #include "ssrf.h"
 #include "dive.h"
+#include "event.h"
 #include "display.h"
 #include "profile.h"
 #include "gaspressures.h"
 #include "pref.h"
 
+#include <stdlib.h>
+
 /*
  * simple structure to track the beginning and end tank pressure as
  * well as the integral of depth over time spent while we have no
