@@ -12,9 +12,12 @@
 #include "ssrf.h"
 #include "dive.h"
 #include "divelist.h" // for init_decompression()
+#include "sample.h"
 #include "subsurface-string.h"
 #include "deco.h"
 #include "errorhelper.h"
+#include "event.h"
+#include "interpolate.h"
 #include "planner.h"
 #include "subsurface-time.h"
 #include "gettext.h"
