@@ -225,9 +225,18 @@ void DiveLogExportDialog::on_buttonBox_accepted()
 void exportProfile(const struct dive *dive, const QString filename)
 {
 	ProfileWidget2 *profile = MainWindow::instance()->graphics;
-	profile->plotDive(dive, true, false, true);
 	profile->setToolTipVisibile(false);
-	QPixmap pix = profile->grab();
+	profile->setPrintMode(true);
+	double scale = profile->getFontPrintScale();
+	profile->setFontPrintScale(4 * scale);
+	profile->plotDive(dive, true, false, true);
+	QImage image = QImage(profile->size() * 4, QImage::Format_RGB32);
+	QPainter paint;
+	paint.begin(&image);
+	profile->render(&paint);
+	image.save(filename);
 	profile->setToolTipVisibile(true);
-	pix.save(filename);
+	profile->setFontPrintScale(scale);
+	profile->setPrintMode(false);
+	profile->plotDive(dive, true);
 }
