@@ -18,7 +18,7 @@
 #include "ui_mainwindow.h"
 #include "ui_plannerDetails.h"
 #include "desktop-widgets/notificationwidget.h"
-#include "desktop-widgets/filterwidget2.h"
+#include "desktop-widgets/filterwidget.h"
 #include "core/applicationstate.h"
 #include "core/gpslocation.h"
 #include "core/dive.h"
@@ -107,7 +107,6 @@ slots:
 	/* log menu actions */
 	void on_actionDownloadDC_triggered();
 	void on_actionDivelogs_de_triggered();
-	void on_actionEditDeviceNames_triggered();
 	void on_actionAddDive_triggered();
 	void on_actionRenumber_triggered();
 	void on_actionAutoGroup_triggered();
@@ -174,7 +173,7 @@ slots:
 
 private:
 	Ui::MainWindow ui;
-	FilterWidget2 filterWidget2;
+	FilterWidget filterWidget;
 	QAction *actionNextDive;
 	QAction *actionPreviousDive;
 	QAction *undoAction;
@@ -199,7 +198,6 @@ private:
 	void writeSettings();
 	int file_save();
 	int file_save_as();
-	void setFileClean();
 	void beginChangeState(CurrentState s);
 	void saveSplitterSizes();
 	void toggleCollapsible(bool toggle);
