@@ -8,6 +8,12 @@
 #include "preferences_units.h"
 #include "preferences_graph.h"
 #include "preferences_network.h"
+#include "preferences_cloud.h"
+#include "preferences_equipment.h"
+#include "preferences_media.h"
+#include "preferences_dc.h"
+#include "preferences_log.h"
+#include "preferences_reset.h"
 
 #include "core/qthelper.h"
 
@@ -47,8 +53,8 @@ PreferencesDialog::PreferencesDialog()
 		QDialogButtonBox::Apply |
 		QDialogButtonBox::Cancel);
 
-	pagesList->setMinimumWidth(120);
-	pagesList->setMaximumWidth(120);
+	pagesList->setMinimumWidth(140);
+	pagesList->setMaximumWidth(140);
 
 	QHBoxLayout *h = new QHBoxLayout();
 	h->addWidget(pagesList);
@@ -65,6 +71,13 @@ PreferencesDialog::PreferencesDialog()
 	addPreferencePage(new PreferencesUnits());
 	addPreferencePage(new PreferencesGraph());
 	addPreferencePage(new PreferencesNetwork());
+	addPreferencePage(new PreferencesCloud());
+	addPreferencePage(new PreferencesEquipment());
+	addPreferencePage(new PreferencesMedia());
+	addPreferencePage(new PreferencesDc());
+	addPreferencePage(new PreferencesLog());
+	addPreferencePage(new PreferencesReset());
+
 	refreshPages();
 
 	connect(pagesList, &QListWidget::currentRowChanged,
