@@ -26,6 +26,7 @@ TabDivePhotos::TabDivePhotos(QWidget *parent)
 	ui->setupUi(this);
 	ui->photosView->setModel(divePictureModel);
 	ui->photosView->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	ui->photosView->setSelectionBehavior(QAbstractItemView::SelectRows);
 	ui->photosView->setResizeMode(QListView::Adjust);
 
 	connect(ui->photosView, &DivePictureWidget::photoDoubleClicked,
@@ -70,8 +71,6 @@ QVector<QString> TabDivePhotos::getSelectedFilenames() const
 	if (!ui->photosView->selectionModel()->hasSelection())
 		return selectedPhotos;
 	QModelIndexList indices = ui->photosView->selectionModel()->selectedRows();
-	if (indices.count() == 0)
-		indices = ui->photosView->selectionModel()->selectedIndexes();
 	selectedPhotos.reserve(indices.count());
 	for (const auto &photo: indices) {
 		if (photo.isValid()) {
@@ -85,7 +84,8 @@ QVector<QString> TabDivePhotos::getSelectedFilenames() const
 
 void TabDivePhotos::removeSelectedPhotos()
 {
-	DivePictureModel::instance()->removePictures(getSelectedFilenames());
+	QModelIndexList indices = ui->photosView->selectionModel()->selectedRows();
+	DivePictureModel::instance()->removePictures(indices);
 }
 
 void TabDivePhotos::openFolderOfSelectedFiles()
@@ -111,13 +111,11 @@ void TabDivePhotos::recalculateSelectedThumbnails()
 
 void TabDivePhotos::saveSubtitles()
 {
-	QVector<QString> selectedPhotos;
+	if (!current_dive)
+		return;
 	if (!ui->photosView->selectionModel()->hasSelection())
 		return;
 	QModelIndexList indices = ui->photosView->selectionModel()->selectedRows();
-	if (indices.count() == 0)
-		indices = ui->photosView->selectionModel()->selectedIndexes();
-	selectedPhotos.reserve(indices.count());
 	for (const auto &photo: indices) {
 		if (photo.isValid()) {
 			QString fileUrl = photo.data(Qt::DisplayPropertyRole).toString();
@@ -131,14 +129,13 @@ void TabDivePhotos::saveSubtitles()
 				if (!duration)
 					continue;
 				struct membuffer b = { 0 };
-				save_subtitles_buffer(&b, &displayed_dive, offset, duration);
+				save_subtitles_buffer(&b, current_dive, offset, duration);
 				char *data = detach_cstring(&b);
 				subtitlefile.open(QIODevice::WriteOnly);
 				subtitlefile.write(data, strlen(data));
 				subtitlefile.close();
 				free(data);
 			}
-
 		}
 	}
 }
