@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "profile-widget/profilewidget2.h"
 #include "qt-models/diveplotdatamodel.h"
+#include "core/event.h"
 #include "core/subsurface-string.h"
 #include "core/qthelper.h"
 #include "core/picture.h"
@@ -1013,15 +1014,19 @@ void ProfileWidget2::wheelEvent(QWheelEvent *event)
 	QPoint toolTipPos = mapFromScene(toolTipItem->pos());
 	if (event->buttons() == Qt::LeftButton)
 		return;
-	if (event->delta() > 0 && zoomLevel < 20) {
+	if (event->angleDelta().y() > 0 && zoomLevel < 20) {
 		scale(zoomFactor, zoomFactor);
 		zoomLevel++;
-	} else if (event->delta() < 0 && zoomLevel > 0) {
+	} else if (event->angleDelta().y() < 0 && zoomLevel > 0) {
 		// Zooming out
 		scale(1.0 / zoomFactor, 1.0 / zoomFactor);
 		zoomLevel--;
 	}
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+	scrollViewTo(event->position().toPoint());
+#else
 	scrollViewTo(event->pos());
+#endif
 	toolTipItem->setPos(mapToScene(toolTipPos));
 }
 
@@ -1377,10 +1382,6 @@ void ProfileWidget2::setPlanState()
 }
 #endif
 
-extern struct ev_select *ev_namelist;
-extern int evn_allocated;
-extern int evn_used;
-
 bool ProfileWidget2::isPlanner()
 {
 	return currentState == PLAN;
@@ -1821,12 +1822,12 @@ int ProfileWidget2::fixHandlerIndex(DiveHandler *activeHandler)
 	if (index > 0 && index < handles.count() - 1) {
 		DiveHandler *before = handles[index - 1];
 		if (before->pos().x() > activeHandler->pos().x()) {
-			handles.swap(index, index - 1);
+			std::swap(handles[index], handles[index - 1]);
 			return index - 1;
 		}
 		DiveHandler *after = handles[index + 1];
 		if (after->pos().x() < activeHandler->pos().x()) {
-			handles.swap(index, index + 1);
+			std::swap(handles[index], handles[index + 1]);
 			return index + 1;
 		}
 	}
