@@ -73,6 +73,7 @@ public:
 		COLUMNS
 	};
 	explicit DivePlotDataModel(QObject *parent = 0);
+	~DivePlotDataModel();
 	int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 	QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
@@ -91,7 +92,6 @@ public:
 
 private:
 	struct plot_info pInfo;
-	int diveId;
 	unsigned int dcNr;
 	struct deco_state plot_deco_state;
 };
