@@ -10,7 +10,6 @@ class GpsListModel : public QAbstractListModel
 {
 	Q_OBJECT
 public:
-
 	enum GpsListRoles {
 		GpsDateRole = Qt::UserRole + 1,
 		GpsNameRole,
@@ -20,15 +19,14 @@ public:
 	};
 
 	static GpsListModel *instance();
-	GpsListModel(QObject *parent = 0);
 	void clear();
 	int rowCount(const QModelIndex &parent = QModelIndex()) const;
 	QHash<int, QByteArray> roleNames() const;
 	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
 	void update();
 private:
+	GpsListModel();
 	QVector<gpsTracker> m_gpsFixes;
-	static GpsListModel *m_instance;
 };
 
 #endif // GPSLISTMODEL_H
