@@ -5,7 +5,7 @@
 # copy the dependency script into this folder
 cp ../../../packaging/android/android-build-wrapper.sh .
 cp ../../../packaging/android/variables.sh .
-cp ../../../packaging/android/qt-installer-noninteractive.qs .
+cp ../../../packaging/android/install-qt.sh .
 
 # create the container (this takes a while)
 sudo docker build -t android-builder --squash .
