@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "testdivesiteduplication.h"
+#include "core/device.h"
 #include "core/dive.h"
 #include "core/divesite.h"
 #include "core/trip.h"
@@ -7,7 +8,8 @@
 
 void TestDiveSiteDuplication::testReadV2()
 {
-	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/TwoTimesTwo.ssrf", &dive_table, &trip_table, &dive_site_table), 0);
+	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/TwoTimesTwo.ssrf", &dive_table, &trip_table,
+			    &dive_site_table, &device_table, &filter_preset_table), 0);
 	QCOMPARE(dive_site_table.nr, 2);
 }
 
